@@ -10,11 +10,13 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Test::Compile; # git description: v2.051-16-g0f87c4a
+package Dist::Zilla::Plugin::Test::Compile; # git description: v2.052-13-gf111d1b
 # ABSTRACT: Common tests to check syntax of your modules, only using core modules
 # KEYWORDS: plugin test compile verify validate load modules scripts
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
-our $VERSION = '2.052';
+
+our $VERSION = '2.053';
+
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
@@ -67,7 +69,7 @@ sub mvp_aliases { return { skip => 'skips', file => 'files' } }
 has skips => (
     isa => 'ArrayRef[Str]',
     traits => ['Array'],
-    handles => { skips => 'elements' },
+    handles => { skips => 'sort' },
     lazy => 1,
     default => sub { [] },
 );
@@ -75,7 +77,7 @@ has skips => (
 has files => (
     isa => 'ArrayRef[Str]',
     traits => ['Array'],
-    handles => { files => 'elements' },
+    handles => { files => 'sort' },
     lazy => 1,
     default => sub { [] },
 );
@@ -92,14 +94,14 @@ has _test_more_version => (
 has _module_filenames  => (
     isa => 'ArrayRef[Str]',
     traits => ['Array'],
-    handles => { _module_filenames => 'elements' },
+    handles => { _module_filenames => 'sort' },
     lazy => 1,
     default => sub { [ map { $_->name } @{shift->found_module_files} ] },
 );
 has _script_filenames => (
     isa => 'ArrayRef[Str]',
     traits => ['Array'],
-    handles => { _script_filenames => 'elements' },
+    handles => { _script_filenames => 'sort' },
     lazy => 1,
     default => sub { [ map { $_->name } @{shift->found_script_files} ] },
 );
@@ -356,7 +358,7 @@ Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.052
+version 2.053
 
 =head1 SYNOPSIS
 
@@ -510,13 +512,6 @@ Karen Etheridge <ether@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Jérôme Quelin.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Ahmad M. Zawawi Olivier Mengué Kent Fredric Randy Stauner Jesse Luehrs Harley Pig David Golden Graham Knop fayland Peter Shangov Chris Weyl Ricardo SIGNES Marcel Gruenauer
@@ -577,6 +572,13 @@ Marcel Gruenauer <hanekomu@gmail.com>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Jérôme Quelin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __DATA__
@@ -585,18 +587,16 @@ use 5.006;
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 
 use Test::More{{ $test_more_version ? " $test_more_version" : '' }};
 {{
-$needs_display
-    ? <<'CODE'
+    $needs_display ? <<'CODE' : ''
 # Skip all tests if you need a display for this test and $ENV{DISPLAY} is not set
 if (not $ENV{DISPLAY} and $^O ne 'MSWin32') {
     plan skip_all => 'Needs DISPLAY';
 }
 CODE
-    : ''
 }}
 plan tests => {{
     my $count = @module_filenames + @script_filenames;
@@ -618,13 +618,11 @@ my @module_files = (
 }}
 
 {{
-$fake_home
-    ? <<'CODE'
+    $fake_home ? <<'CODE' : '# no fake home requested';
 # fake home for cpan-testers
 use File::Temp;
 local $ENV{HOME} = File::Temp::tempdir( CLEANUP => 1 );
 CODE
-    : '# no fake home requested';
 }}
 
 my $inc_switch = -d 'blib' ? '-Mblib' : '-Ilib';
@@ -647,6 +645,9 @@ for my $lib (@module_files)
     waitpid($pid, 0);
     is($?, 0, "$lib loaded ok");
 
+    shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
+        and not eval { blib->VERSION('1.01') };
+
     if (@_warnings)
     {
         warn @_warnings;
@@ -655,8 +656,7 @@ for my $lib (@module_files)
 }
 
 {{
-@script_filenames
-    ? <<'CODE'
+    @script_filenames ? <<'CODE' : '';
 foreach my $file (@scripts)
 { SKIP: {
     open my $fh, '<', $file or warn("Unable to open $file: $!"), next;
@@ -673,7 +673,10 @@ foreach my $file (@scripts)
     waitpid($pid, 0);
     is($?, 0, "$file compiled ok");
 
-   # in older perls, -c output is simply the file portion of the path being tested
+    shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
+        and not eval { blib->VERSION('1.01') };
+
+    # in older perls, -c output is simply the file portion of the path being tested
     if (@_warnings = grep { !/\bsyntax OK$/ }
         grep { chomp; $_ ne (File::Spec->splitpath($file))[2] } @_warnings)
     {
@@ -683,7 +686,6 @@ foreach my $file (@scripts)
 } }
 
 CODE
-    : '';
 }}
 
 {{
